angular.module('bookService', ["httpHandlerModule","resourceModule","UserModule"])

.factory('commonFactory', function(commonFunctionFactory) {
  var factory ={};
  //时间格式转换
  factory.timeTransform = {

    nowDay: function (date) {
      var nowDay = commonFunctionFactory.displayText.DateToDayText((new Date((date/1000+86400)*1000)));
      return nowDay;
    },
    endDay: function (date) {
      var endDay = commonFunctionFactory.displayText.DateToDayText((new Date((date/1000+86400*7)*1000)));
      return endDay;
    }
  };

  //单个对象转换为数组
  factory.toArray = function (data) {
    if(data instanceof Array != true){
      var tmp =[];
      tmp.push(data);
      return tmp;
    }
    return data;
  };

  return factory;

})

.service('service',function($http, httpHandlerService,resourceFactory,commonFactory,userService){
  var service = {};

  //获取向上转院列表
  service.getDiagnosisAskList = function (data, $scope) {
    httpHandlerService.diagnosisAskRequest(data, resourceFactory.operateCode.get,
      function (response) {
        if (response.Header.StatusCode == 0) {
          $scope.DiagnosisAsk = response.Body.DiagnosisAskList;
          $scope.DiagnosisAskList = $scope.DiagnosisAsk;
          //搜索条件清空
          $scope.searchPar = {
            BeginRow: 0,
            Rows: 100000,
            Name: "",
            TurnOutDateBegin: "",
            TurnOutDateEnd: "",
          };
          if (response.Body.DiagnosisAskList != null && response.Body.DiagnosisAskList.length > 0) {
            $scope.showDetail(response.Body.DiagnosisAskList[0]);
          }
        }
        $("#loading_div").modal("hide");
      },
      function (response) {
        console.log(response);
      }
    );
  };

  //获取科室列表
  service.getDepartment = function ($scope,$rootScope) {
    httpHandlerService.getDepartmentRequest ({}, resourceFactory.operateCode.get,
      function (response) {
        if (response.Header.StatusCode == 0) {
          $scope.departmentList = response.Body.deptInfo;
          $rootScope.departmentList = $scope.departmentList;
          console.log($rootScope.departmentList);
        }
        else {
          console.log(response);
        }
      },
      function (response) {
        console.log(response);
      }
    );
  };

//获取绿色通道科室数据（排除未开放科室）
  service.getDepartmentCanOrderLocalRequest = function (data, $scope) {
    httpHandlerService.getDepartmentCanOrderLocalRequest(data, resourceFactory.operateCode.get,
      function (response) {
        if (response.Header.StatusCode == 0) {
          $scope.RegInfoBeCurrent = response.Body.DepartmentList;
        }
      },
      function (response) {
        console.error(response);
      }
    );
  };

  //获取科室医生数据
  service.getDoctorByDepartmentIDRequest = function (data, $scope) {
    httpHandlerService.getDoctorByDepartmentIDRequest(data, resourceFactory.operateCode.get,
      function (response) {
        console.log(response);
        if (response.Header.StatusCode == 0) {
          if ($scope.SelectDoctor == 0) {  //预约
            $scope.DepartmentByRequest = response.Body.UserList;
          } else {
            $scope.DepartmentUser = response.Body.UserList;
          }
        } else {
          $scope.DepartmentUser = [];
        }
      },
      function (response) {
        console.error(response);
      }
    );
  };

  //获取预约信息
  service.getRegInfo = function ($scope,doctor,$rootScope) {
    var request ={
      "deptId": doctor.deptId,
      "doctorId": doctor.doctorId,
      "startDate": commonFactory.timeTransform.nowDay(new Date()),
      "endDate":commonFactory.timeTransform.endDay(new Date())
    };
    httpHandlerService.getRegInfoRequest (request, resourceFactory.operateCode.get,
      function (response) {
        if (response.Header.StatusCode == 0) {
          $scope.regInfo = response.Body.regInfo;
          $rootScope.regInfo = $scope.regInfo;
          //只有一天的预约信息
          $scope.regInfo.TimeRegInfoList = commonFactory.toArray($scope.regInfo.TimeRegInfoList);
          $rootScope.regInfo.TimeRegInfoList = $scope.regInfo.TimeRegInfoList;
          //只有一个时段的预约信息
          for(var i=0; i<$scope.regInfo.TimeRegInfoList.length;i++){
            $scope.regInfo.TimeRegInfoList[i].timeRegInfo = commonFactory.toArray($scope.regInfo.TimeRegInfoList[i].timeRegInfo);
            $rootScope.regInfo.TimeRegInfoList[i].timeRegInfo = $scope.regInfo.TimeRegInfoList[i].timeRegInfo
          }
          $scope.bookInfo.regDate = $scope.regInfo.TimeRegInfoList[0].regDate;
          console.log($scope.regInfo);
        }
        else {
          console.log(response);
        }
      },
      function (response) {
        console.log(response);
      }
    );
  };

  //挂号申请
  service.addOrder = function ($scope,request,$rootScope) {
    httpHandlerService.addOrderRequest (request, resourceFactory.operateCode.insert,
      function (response) {
        if (response.Header.StatusCode == 0) {
          $scope.orderinfo = response.body;
          console.log($scope.orderinfo);
        }
        else {
          console.log(response);
        }
      },
      function (response) {
        console.log(response);
      }
    );
  };

  //获取预约挂号科室医生可预约详情
  service.getRegInfoBeCurrentRequest = function (data, $scope) {
    $("#loading_div").modal("show");
    httpHandlerService.getRegInfoBeCurrentRequest(data, resourceFactory.operateCode.get,
      function (response) {
        if (response.Header.StatusCode == 0) {
          $scope.regInfo = response.Body.regInfo;
          //单个对象转换为数组
          if ($scope.regInfo.TimeRegInfoList instanceof Array != true) {
            var tmp = [];
            tmp.push($scope.regInfo.TimeRegInfoList);
            $scope.regInfo.TimeRegInfoList = tmp;
          }
        } else if (response.Header.StatusCode == 6) {
          //alert("服务请求错误!");
          navigator.notification.alert("服务请求错误!",function(){},"提示消息","确定");
        } else if (response.Header.StatusCode == 8) {
          //alert("没有号源信息");
          navigator.notification.alert("没有号源信息!",function(){},"提示消息","确定");
        } else {
          $scope.regInfo = [];
        }
        $("#loading_div").modal("hide");
      },
      function (response) {
        console.error(response);
      }
    );
  };

  //提交预约接口
  service.InsertaddOrderBeCurrentRequest = function (data, $scope) {
    httpHandlerService.addOrderBeCurrentRequest(data, resourceFactory.operateCode.insert,
      function (response) {
        if (response.Header.StatusCode == 0) {
          service.getDiagnosisAskList($scope.searchPar, $scope);
          //alert("预约成功");
          navigator.notification.alert("预约成功!",function(){},"提示消息","确定");
          console.log($scope.DiagnosisAsk.Registered.OrderNo);
        }else if(response.Header.StatusCode == 8){
          //alert("已经有预约了，不能重复预约.");
          navigator.notification.alert("已经有预约了，不能重复预约!",function(){},"提示消息","确定");
        }
        else{
          //alert("预约失败");
          navigator.notification.alert("预约失败",function(){},"提示消息","确定");
          console.log(response);
        }
      },
      function (response) {
        console.error(response);
      }
    );
  };

  return service;
});

